# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: delta_enclave_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='delta_enclave_api.proto',
  package='delta_enclave_api',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17\x64\x65lta_enclave_api.proto\x12\x11\x64\x65lta_enclave_api\"m\n\x07Request\x12\x16\n\x0c\x61vatoRequest\x18\x01 \x01(\x0cH\x00\x12?\n\x10\x65xtensionMessage\x18\x02 \x01(\x0b\x32#.delta_enclave_api.ExtensionMessageH\x00\x42\t\n\x07request\"1\n\x10\x45xtensionMessage\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0f\n\x07payload\x18\x02 \x02(\x0c\"T\n\x08Response\x12\x1c\n\x12successfulResponse\x18\x01 \x01(\x0cH\x00\x12\x1e\n\x14unsuccessfulResponse\x18\x02 \x01(\tH\x00\x42\n\n\x08response\"o\n\x0f\x44\x61taNoncePubkey\x12\x0c\n\x04\x64\x61ta\x18\x01 \x02(\x0c\x12\r\n\x05nonce\x18\x02 \x02(\x0c\x12\x0e\n\x06pubkey\x18\x03 \x02(\x0c\x12/\n\x04\x61uth\x18\x04 \x01(\x0b\x32!.delta_enclave_api.Authentication\"5\n\x0e\x41uthentication\x12#\n\x03pki\x18\x01 \x02(\x0b\x32\x16.delta_enclave_api.Pki\":\n\x03Pki\x12\x11\n\tcertChain\x18\x01 \x02(\x0c\x12\x11\n\tsignature\x18\x02 \x02(\x0c\x12\r\n\x05idMac\x18\x03 \x02(\x0c\"(\n\tDataNonce\x12\x0c\n\x04\x64\x61ta\x18\x01 \x02(\x0c\x12\r\n\x05nonce\x18\x02 \x02(\x0c\"j\n\x16SealedEncryptedMessage\x12\x36\n\x10\x65ncryptedMessage\x18\x01 \x02(\x0b\x32\x1c.delta_enclave_api.DataNonce\x12\x18\n\x10sealingKeyParams\x18\x02 \x02(\x0c\"W\n\x10\x45ncryptionHeader\x12/\n\x08\x63hilyKey\x18\x01 \x01(\x0b\x32\x1b.delta_enclave_api.ChilyKeyH\x00\x42\x12\n\x10\x65ncryptionHeader\"2\n\x08\x43hilyKey\x12\r\n\x05keyId\x18\x01 \x02(\x0c\x12\x17\n\x0f\x65ncryptionNonce\x18\x02 \x02(\x0c\"\x93\x01\n\x0fIntegrityHeader\x12\x33\n\nbodySha256\x18\x01 \x01(\x0b\x32\x1d.delta_enclave_api.BodySha256H\x00\x12\x37\n\x0cresultSha256\x18\x02 \x01(\x0b\x32\x1f.delta_enclave_api.ResultSha256H\x00\x42\x12\n\x10integrity_header\"\x0c\n\nBodySha256\")\n\x0cResultSha256\x12\x19\n\x11\x63omputationSha256\x18\x01 \x02(\x0c\" \n\rVersionHeader\x12\x0f\n\x07version\x18\x01 \x02(\x03\"=\n\x0b\x43hunkHeader\x12\x14\n\x0c\x65xtraEntropy\x18\x01 \x02(\x0c\x12\x18\n\x10\x66ormatIdentifier\x18\x02 \x02(\t'
)




_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='delta_enclave_api.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='avatoRequest', full_name='delta_enclave_api.Request.avatoRequest', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extensionMessage', full_name='delta_enclave_api.Request.extensionMessage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request', full_name='delta_enclave_api.Request.request',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=46,
  serialized_end=155,
)


_EXTENSIONMESSAGE = _descriptor.Descriptor(
  name='ExtensionMessage',
  full_name='delta_enclave_api.ExtensionMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='delta_enclave_api.ExtensionMessage.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='delta_enclave_api.ExtensionMessage.payload', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=206,
)


_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='delta_enclave_api.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='successfulResponse', full_name='delta_enclave_api.Response.successfulResponse', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsuccessfulResponse', full_name='delta_enclave_api.Response.unsuccessfulResponse', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response', full_name='delta_enclave_api.Response.response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=208,
  serialized_end=292,
)


_DATANONCEPUBKEY = _descriptor.Descriptor(
  name='DataNoncePubkey',
  full_name='delta_enclave_api.DataNoncePubkey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='delta_enclave_api.DataNoncePubkey.data', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='delta_enclave_api.DataNoncePubkey.nonce', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pubkey', full_name='delta_enclave_api.DataNoncePubkey.pubkey', index=2,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='delta_enclave_api.DataNoncePubkey.auth', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=294,
  serialized_end=405,
)


_AUTHENTICATION = _descriptor.Descriptor(
  name='Authentication',
  full_name='delta_enclave_api.Authentication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pki', full_name='delta_enclave_api.Authentication.pki', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=460,
)


_PKI = _descriptor.Descriptor(
  name='Pki',
  full_name='delta_enclave_api.Pki',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certChain', full_name='delta_enclave_api.Pki.certChain', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='delta_enclave_api.Pki.signature', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idMac', full_name='delta_enclave_api.Pki.idMac', index=2,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=520,
)


_DATANONCE = _descriptor.Descriptor(
  name='DataNonce',
  full_name='delta_enclave_api.DataNonce',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='delta_enclave_api.DataNonce.data', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='delta_enclave_api.DataNonce.nonce', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=522,
  serialized_end=562,
)


_SEALEDENCRYPTEDMESSAGE = _descriptor.Descriptor(
  name='SealedEncryptedMessage',
  full_name='delta_enclave_api.SealedEncryptedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='encryptedMessage', full_name='delta_enclave_api.SealedEncryptedMessage.encryptedMessage', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sealingKeyParams', full_name='delta_enclave_api.SealedEncryptedMessage.sealingKeyParams', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=564,
  serialized_end=670,
)


_ENCRYPTIONHEADER = _descriptor.Descriptor(
  name='EncryptionHeader',
  full_name='delta_enclave_api.EncryptionHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chilyKey', full_name='delta_enclave_api.EncryptionHeader.chilyKey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='encryptionHeader', full_name='delta_enclave_api.EncryptionHeader.encryptionHeader',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=672,
  serialized_end=759,
)


_CHILYKEY = _descriptor.Descriptor(
  name='ChilyKey',
  full_name='delta_enclave_api.ChilyKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyId', full_name='delta_enclave_api.ChilyKey.keyId', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encryptionNonce', full_name='delta_enclave_api.ChilyKey.encryptionNonce', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=761,
  serialized_end=811,
)


_INTEGRITYHEADER = _descriptor.Descriptor(
  name='IntegrityHeader',
  full_name='delta_enclave_api.IntegrityHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bodySha256', full_name='delta_enclave_api.IntegrityHeader.bodySha256', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resultSha256', full_name='delta_enclave_api.IntegrityHeader.resultSha256', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='integrity_header', full_name='delta_enclave_api.IntegrityHeader.integrity_header',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=814,
  serialized_end=961,
)


_BODYSHA256 = _descriptor.Descriptor(
  name='BodySha256',
  full_name='delta_enclave_api.BodySha256',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=975,
)


_RESULTSHA256 = _descriptor.Descriptor(
  name='ResultSha256',
  full_name='delta_enclave_api.ResultSha256',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='computationSha256', full_name='delta_enclave_api.ResultSha256.computationSha256', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=977,
  serialized_end=1018,
)


_VERSIONHEADER = _descriptor.Descriptor(
  name='VersionHeader',
  full_name='delta_enclave_api.VersionHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='delta_enclave_api.VersionHeader.version', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1020,
  serialized_end=1052,
)


_CHUNKHEADER = _descriptor.Descriptor(
  name='ChunkHeader',
  full_name='delta_enclave_api.ChunkHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='extraEntropy', full_name='delta_enclave_api.ChunkHeader.extraEntropy', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='formatIdentifier', full_name='delta_enclave_api.ChunkHeader.formatIdentifier', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1054,
  serialized_end=1115,
)

_REQUEST.fields_by_name['extensionMessage'].message_type = _EXTENSIONMESSAGE
_REQUEST.oneofs_by_name['request'].fields.append(
  _REQUEST.fields_by_name['avatoRequest'])
_REQUEST.fields_by_name['avatoRequest'].containing_oneof = _REQUEST.oneofs_by_name['request']
_REQUEST.oneofs_by_name['request'].fields.append(
  _REQUEST.fields_by_name['extensionMessage'])
_REQUEST.fields_by_name['extensionMessage'].containing_oneof = _REQUEST.oneofs_by_name['request']
_RESPONSE.oneofs_by_name['response'].fields.append(
  _RESPONSE.fields_by_name['successfulResponse'])
_RESPONSE.fields_by_name['successfulResponse'].containing_oneof = _RESPONSE.oneofs_by_name['response']
_RESPONSE.oneofs_by_name['response'].fields.append(
  _RESPONSE.fields_by_name['unsuccessfulResponse'])
_RESPONSE.fields_by_name['unsuccessfulResponse'].containing_oneof = _RESPONSE.oneofs_by_name['response']
_DATANONCEPUBKEY.fields_by_name['auth'].message_type = _AUTHENTICATION
_AUTHENTICATION.fields_by_name['pki'].message_type = _PKI
_SEALEDENCRYPTEDMESSAGE.fields_by_name['encryptedMessage'].message_type = _DATANONCE
_ENCRYPTIONHEADER.fields_by_name['chilyKey'].message_type = _CHILYKEY
_ENCRYPTIONHEADER.oneofs_by_name['encryptionHeader'].fields.append(
  _ENCRYPTIONHEADER.fields_by_name['chilyKey'])
_ENCRYPTIONHEADER.fields_by_name['chilyKey'].containing_oneof = _ENCRYPTIONHEADER.oneofs_by_name['encryptionHeader']
_INTEGRITYHEADER.fields_by_name['bodySha256'].message_type = _BODYSHA256
_INTEGRITYHEADER.fields_by_name['resultSha256'].message_type = _RESULTSHA256
_INTEGRITYHEADER.oneofs_by_name['integrity_header'].fields.append(
  _INTEGRITYHEADER.fields_by_name['bodySha256'])
_INTEGRITYHEADER.fields_by_name['bodySha256'].containing_oneof = _INTEGRITYHEADER.oneofs_by_name['integrity_header']
_INTEGRITYHEADER.oneofs_by_name['integrity_header'].fields.append(
  _INTEGRITYHEADER.fields_by_name['resultSha256'])
_INTEGRITYHEADER.fields_by_name['resultSha256'].containing_oneof = _INTEGRITYHEADER.oneofs_by_name['integrity_header']
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['ExtensionMessage'] = _EXTENSIONMESSAGE
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['DataNoncePubkey'] = _DATANONCEPUBKEY
DESCRIPTOR.message_types_by_name['Authentication'] = _AUTHENTICATION
DESCRIPTOR.message_types_by_name['Pki'] = _PKI
DESCRIPTOR.message_types_by_name['DataNonce'] = _DATANONCE
DESCRIPTOR.message_types_by_name['SealedEncryptedMessage'] = _SEALEDENCRYPTEDMESSAGE
DESCRIPTOR.message_types_by_name['EncryptionHeader'] = _ENCRYPTIONHEADER
DESCRIPTOR.message_types_by_name['ChilyKey'] = _CHILYKEY
DESCRIPTOR.message_types_by_name['IntegrityHeader'] = _INTEGRITYHEADER
DESCRIPTOR.message_types_by_name['BodySha256'] = _BODYSHA256
DESCRIPTOR.message_types_by_name['ResultSha256'] = _RESULTSHA256
DESCRIPTOR.message_types_by_name['VersionHeader'] = _VERSIONHEADER
DESCRIPTOR.message_types_by_name['ChunkHeader'] = _CHUNKHEADER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
  'DESCRIPTOR' : _REQUEST,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.Request)
  })
_sym_db.RegisterMessage(Request)

ExtensionMessage = _reflection.GeneratedProtocolMessageType('ExtensionMessage', (_message.Message,), {
  'DESCRIPTOR' : _EXTENSIONMESSAGE,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.ExtensionMessage)
  })
_sym_db.RegisterMessage(ExtensionMessage)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.Response)
  })
_sym_db.RegisterMessage(Response)

DataNoncePubkey = _reflection.GeneratedProtocolMessageType('DataNoncePubkey', (_message.Message,), {
  'DESCRIPTOR' : _DATANONCEPUBKEY,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.DataNoncePubkey)
  })
_sym_db.RegisterMessage(DataNoncePubkey)

Authentication = _reflection.GeneratedProtocolMessageType('Authentication', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATION,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.Authentication)
  })
_sym_db.RegisterMessage(Authentication)

Pki = _reflection.GeneratedProtocolMessageType('Pki', (_message.Message,), {
  'DESCRIPTOR' : _PKI,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.Pki)
  })
_sym_db.RegisterMessage(Pki)

DataNonce = _reflection.GeneratedProtocolMessageType('DataNonce', (_message.Message,), {
  'DESCRIPTOR' : _DATANONCE,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.DataNonce)
  })
_sym_db.RegisterMessage(DataNonce)

SealedEncryptedMessage = _reflection.GeneratedProtocolMessageType('SealedEncryptedMessage', (_message.Message,), {
  'DESCRIPTOR' : _SEALEDENCRYPTEDMESSAGE,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.SealedEncryptedMessage)
  })
_sym_db.RegisterMessage(SealedEncryptedMessage)

EncryptionHeader = _reflection.GeneratedProtocolMessageType('EncryptionHeader', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTIONHEADER,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.EncryptionHeader)
  })
_sym_db.RegisterMessage(EncryptionHeader)

ChilyKey = _reflection.GeneratedProtocolMessageType('ChilyKey', (_message.Message,), {
  'DESCRIPTOR' : _CHILYKEY,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.ChilyKey)
  })
_sym_db.RegisterMessage(ChilyKey)

IntegrityHeader = _reflection.GeneratedProtocolMessageType('IntegrityHeader', (_message.Message,), {
  'DESCRIPTOR' : _INTEGRITYHEADER,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.IntegrityHeader)
  })
_sym_db.RegisterMessage(IntegrityHeader)

BodySha256 = _reflection.GeneratedProtocolMessageType('BodySha256', (_message.Message,), {
  'DESCRIPTOR' : _BODYSHA256,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.BodySha256)
  })
_sym_db.RegisterMessage(BodySha256)

ResultSha256 = _reflection.GeneratedProtocolMessageType('ResultSha256', (_message.Message,), {
  'DESCRIPTOR' : _RESULTSHA256,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.ResultSha256)
  })
_sym_db.RegisterMessage(ResultSha256)

VersionHeader = _reflection.GeneratedProtocolMessageType('VersionHeader', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONHEADER,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.VersionHeader)
  })
_sym_db.RegisterMessage(VersionHeader)

ChunkHeader = _reflection.GeneratedProtocolMessageType('ChunkHeader', (_message.Message,), {
  'DESCRIPTOR' : _CHUNKHEADER,
  '__module__' : 'delta_enclave_api_pb2'
  # @@protoc_insertion_point(class_scope:delta_enclave_api.ChunkHeader)
  })
_sym_db.RegisterMessage(ChunkHeader)


# @@protoc_insertion_point(module_scope)



from typing import List
from typing_extensions import TypedDict

__all__ = ["EnclaveIdentifier", "FileDescription"]

class UserResponse(TypedDict):
    id: str
    email: str

class UserCsrRequest(TypedDict):
    csrPem: str

class UserCsrResponse(TypedDict):
    certChainPem: str

class SystemCaResponse(TypedDict):
    rootCertificate: str

class CreateSessionRequest(TypedDict):
    enclaveIdentifier: str

class SessionJsonResponse(TypedDict):
    sessionId: str
    enclaveIdentifier: str

class FinalizeUpload(TypedDict):
    uploadId: str
    manifest: str
    name: str
    manifestHash: str
    chunks: List[str]

class EnclaveIdentifier(TypedDict):
    """
    This class identifies an enclave service type and version
    """
    enclaveIdentifier: str
    version: str

class ChunkWrapper(TypedDict):
    hash: str
    data: str

class EnclaveIdentifiersResponse(TypedDict):
    enclaveIdentifiers: List[EnclaveIdentifier]

class UploadDescription(TypedDict):
    uploadId: str

class ChunkDescription(TypedDict):
    chunkHash: str

class DataRoomDescription(TypedDict):
    dataRoomId: str
    tableName: str

class PartialFileDescription(TypedDict):
    dataRoomIds: List[DataRoomDescription]

class FileDescription(TypedDict):
    """
    This class includes information about an uploaded dataset
    """
    manifestHash: str
    filename: str
    chunks: List[ChunkDescription]
    dataRoomIds: List[DataRoomDescription]

class SignatureResponse(TypedDict):
    type: str
    data: List[int]


class B64EncodedMessage(TypedDict):
    data: str

class FatquoteResBody(TypedDict):
    signature: SignatureResponse
    response: str
    certificate: str

class DatasetManifestMetadata(TypedDict):
    name: str
    manifestHash: str
    chunks: List[str]




from __future__ import annotations
import chily
import hmac
import json
import time
from base64 import b64encode, b64decode
from cryptography.hazmat.primitives.kdf.hkdf import HKDF
from cryptography.hazmat.primitives import hashes
from google.protobuf.message import Message
from typing import Tuple, List, TYPE_CHECKING
from dataclasses import dataclass
from typing import Any, TYPE_CHECKING, Dict
from .api import Endpoints
from .authentication import Auth, Sigma
from .proto.data_room_pb2 import DataRoom
from .proto.delta_enclave_api_pb2 import Request, Response, DataNoncePubkey
from .proto.waterfront_pb2 import (
        WaterfrontRequest, WaterfrontResponse, CreateDataRoomResponse,
        RetrieveDataRoomStatusResponse,
        DataRoomStatus, SqlQueryResponse, SqlQueryFinished
)
from .proto.length_delimited import parse_length_delimited, serialize_length_delimited
from .storage import Key
from .types import FatquoteResBody, B64EncodedMessage
from .verification import QuoteBody, Verification
if TYPE_CHECKING:
    from .client import Client

__all__ = ["Session", "SessionOptions", "VerificationOptions", "PollingOptions"]

def datanoncepubkey_to_message(
        encrypted_data: bytes,
        nonce: bytes,
        pubkey: bytes,
        sigma_auth: Sigma
) -> bytes:
    message = DataNoncePubkey()
    message.data = encrypted_data
    message.nonce = nonce
    message.pubkey = pubkey
    message.auth.pki.certChain = sigma_auth.get_cert_chain()
    message.auth.pki.signature = sigma_auth.get_signature()
    message.auth.pki.idMac = sigma_auth.get_mac_tag()
    return serialize_length_delimited(message)


def message_to_datanoncepubkey(message: bytes) -> Tuple[bytes, bytes, bytes]:
    parsed_msg = DataNoncePubkey()
    parse_length_delimited(message, parsed_msg)
    return (parsed_msg.data, parsed_msg.nonce, parsed_msg.pubkey)


@dataclass
class Fatquote():
    signature: bytes
    certificate: bytes
    message: bytes


@dataclass
class VerificationOptions():
    """ Customize verification options """
    accept_debug: bool
    """ Accept enclaves with `DEBUG` flag """
    accept_configuration_needed: bool
    """ Accept enclaves with `CONFIGURATION_NEEDED` flag """
    accept_group_out_of_date: bool
    """ Accept enclaves with `GROUP_OUT_OF_DATE` flag """


@dataclass
class SessionOptions():
    """ Customize session options """
    verification_options: VerificationOptions


@dataclass
class PollingOptions():
    """ Customize polling options """
    interval: int
    """ Interval between requests """


class Session():
    """
    This class manages the communication with an enclave
    """
    client: Client
    session_id: str
    enclave_identifier: str
    auth: Dict[str, Auth]
    keypair: Any
    fatquote: Fatquote
    quote: QuoteBody

    def __init__(
            self,
            client: Client,
            session_id: str,
            enclave_identifier: str,
            auth: Dict[str, Auth],
            options: SessionOptions
    ):
        """
        Create a new `Session` instance using `decentriq_platform.Client.create_session`
        """
        url = Endpoints.SESSION_FATQUOTE.replace(":sessionId", session_id)
        response: FatquoteResBody = client.api.get(url).json()
        certificate = response["certificate"].encode("utf-8")
        message = response["response"].encode("utf-8")
        signature = bytes(response["signature"]["data"])
        fatquote = Fatquote(signature, certificate, message)
        verification_options = options.verification_options
        verification = Verification(
            expected_measurement=enclave_identifier,
            accept_debug=verification_options.accept_debug,
            accept_configuration_needed=verification_options.accept_configuration_needed,
            accept_group_out_of_date=verification_options.accept_group_out_of_date,
        )
        quote = verification.verify(certificate, message, signature)
        self.client = client
        self.session_id = session_id
        self.enclave_identifier = enclave_identifier
        self.auth = auth
        self.keypair = chily.Keypair.from_random()
        self.fatquote = fatquote
        self.quote = quote

    def create_data_room(
            self,
            data_room: DataRoom,
            role: str = None
    ) -> CreateDataRoomResponse:
        """
        Create a DataRoom with the provided protobuf `data_room` configuration object
        """
        req = WaterfrontRequest()
        req.createDataRoomRequest.dataRoom.CopyFrom(data_room)

        _, auth = self._get_auth_for_role(role)
        response = self._send_and_parse_message(req, auth)
        if not response.HasField("createDataRoomResponse"):
            raise Exception(
                "Expected createDataRoomResponse, got "
                + response.WhichOneof("waterfront_response")
            )
        return response.createDataRoomResponse

    def retrieve_data_room_status(
        self,
        data_room_hash: bytes,
        role: str = None
    ) -> RetrieveDataRoomStatusResponse:
        """
        Returns the status of the DataRoom
        """
        role, auth = self._get_auth_for_role(role)
        req = WaterfrontRequest()
        req.retrieveDataRoomStatusRequest.dataRoomHash = data_room_hash
        req.retrieveDataRoomStatusRequest.auth.role = role

        access_token = auth._get_access_token()
        if access_token is not None:
            req.retrieveDataRoomStatusRequest.auth.passwordSha256 = access_token

        response = self._send_and_parse_message(req, auth)
        if not response.HasField("retrieveDataRoomStatusResponse"):
            raise Exception(
                "Expected retrieveDataRoomStatusResponse, got "
                + response.WhichOneof("waterfront_response")
            )
        return response.retrieveDataRoomStatusResponse

    def update_data_room_status(
        self,
        data_room_hash: bytes,
        status: DataRoomStatus,
        role: str = None
    ):
        """
        Updates the status of the DataRoom
        """
        role, auth = self._get_auth_for_role(role)
        req = WaterfrontRequest()
        req.updateDataRoomStatusRequest.dataRoomHash = data_room_hash
        req.updateDataRoomStatusRequest.auth.role = role

        access_token = auth._get_access_token()
        if access_token is not None:
            req.updateDataRoomStatusRequest.auth.passwordSha256 = access_token

        req.updateDataRoomStatusRequest.status = status # type: ignore
        response = self._send_and_parse_message(req, auth)
        if not response.HasField("updateDataRoomStatusResponse"):
            raise Exception(
                "Expected updateDataRoomStatusResponse, got "
                + response.WhichOneof("waterfront_response")
            )
        return response.updateDataRoomStatusResponse

    def retrieve_data_room(self, data_room_hash: bytes, role: str = None) -> DataRoom:
        """
        Returns the underlying protobuf configuration object for the DataRoom
        """
        req = WaterfrontRequest()
        req.retrieveDataRoomRequest.dataRoomHash = data_room_hash

        role_name, auth = self._get_auth_for_role(role)
        req.retrieveDataRoomRequest.auth.role = role_name

        access_token = auth._get_access_token()
        if access_token is not None:
            req.retrieveDataRoomRequest.auth.passwordSha256 = access_token

        response = self._send_and_parse_message(req, auth)
        if not response.HasField("retrieveDataRoomResponse"):
            raise Exception(
                "Expected retrieveDataRoomResponse, got "
                + response.WhichOneof("waterfront_response")
            )
        return response.retrieveDataRoomResponse.dataRoom

    def retrieve_audit_log(self, data_room_hash: bytes, role: str = None) -> bytes:
        """
        Returns the audit log for the DataRoom
        """
        req = WaterfrontRequest()
        req.retrieveAuditLogRequest.dataRoomHash = data_room_hash

        role_name, auth = self._get_auth_for_role(role)
        req.retrieveAuditLogRequest.auth.role = role_name

        access_token = auth._get_access_token()
        if access_token is not None:
            req.retrieveAuditLogRequest.auth.passwordSha256 = access_token

        response = self._send_and_parse_message(req, auth)
        if not response.HasField("retrieveAuditLogResponse"):
            raise Exception(
                "Expected retrieveAuditLogResponse, got "
                + response.WhichOneof("waterfront_response")
            )
        return response.retrieveAuditLogResponse.data

    def publish_dataset_to_data_room(
            self,
            user_id: str,
            manifest_hash: bytes,
            data_room_hash: bytes,
            data_room_table_name: str,
            key: Key,
            role: str = None
    ):
        """
        Publishes a dataset to the DataRoom
        """
        current_file = self.client.get_user_file(user_id, manifest_hash)
        req = WaterfrontRequest()
        req.publishDatasetToDataRoomRequest.manifestHash = manifest_hash
        req.publishDatasetToDataRoomRequest.dataRoomHash = data_room_hash
        req.publishDatasetToDataRoomRequest.dataRoomTableName = data_room_table_name
        req.publishDatasetToDataRoomRequest.encryptionKey.material = key.material
        req.publishDatasetToDataRoomRequest.encryptionKey.salt = key.salt

        role_name, auth = self._get_auth_for_role(role)
        req.publishDatasetToDataRoomRequest.auth.role = role_name

        access_token = auth._get_access_token()
        if access_token is not None:
            req.publishDatasetToDataRoomRequest.auth.passwordSha256 = access_token

        response = self._send_and_parse_message(req, auth)
        if not response.HasField("publishDatasetToDataRoomResponse"):
            raise Exception(
                "Expected publishDatasetToDataRoomResponse, got "
                + response.WhichOneof("waterfront_response")
            )
        self.client._add_dataroom_to_user_file(user_id, data_room_hash, data_room_table_name, current_file)

    def retrieve_provisioned_datasests(
        self,
        data_room_hash: bytes,
        role: str = None
    ):
        """
        Returns the datasets published to the DataRoom
        """
        role, auth = self._get_auth_for_role(role)
        req = WaterfrontRequest()
        req.retrievePublishedDatasetRequest.dataRoomHash = data_room_hash
        req.retrievePublishedDatasetRequest.auth.role = role

        access_token = auth._get_access_token()
        if access_token is not None:
            req.retrievePublishedDatasetRequest.auth.passwordSha256 = access_token

        response = self._send_and_parse_message(req, auth)
        if not response.HasField("retrievePublishedDatasetResponse"):
            raise Exception(
                "Expected retrievePublishedDatasetRequest, got "
                + response.WhichOneof("waterfront_response")
            )
        return response.retrievePublishedDatasetResponse

    def remove_published_dataset(
        self,
        user_id: str,
        manifest_hash: bytes,
        data_room_hash: bytes,
        data_room_table_name: str,
        role: str = None
    ):
        """
        Removes a published dataset from the DataRoom
        """
        current_file = self.client.get_user_file(user_id, manifest_hash)
        req = WaterfrontRequest()
        req.removePublishedDatasetRequest.manifestHash = manifest_hash
        req.removePublishedDatasetRequest.dataRoomHash = data_room_hash
        req.removePublishedDatasetRequest.dataRoomTableName = data_room_table_name

        role_name, auth = self._get_auth_for_role(role)
        req.removePublishedDatasetRequest.auth.role = role_name

        access_token = auth._get_access_token()
        if access_token is not None:
            req.removePublishedDatasetRequest.auth.passwordSha256 = access_token

        response = self._send_and_parse_message(req, auth)
        if not response.HasField("removePublishedDatasetResponse"):
            raise Exception(
                "Expected removePublishedDatasetResponse, got "
                + response.WhichOneof("waterfront_response")
            )
        self.client._add_dataroom_to_user_file(user_id, data_room_hash, data_room_table_name, current_file)

    def validate_queries(
        self,
        data_room: DataRoom,
        role: str = None
    ):
        """
        Validates the SQL queries in the provided DataRoom protobuf configuration object
        """
        req = WaterfrontRequest()
        req.validateQueriesRequest.dataRoom.CopyFrom(data_room)

        _, auth = self._get_auth_for_role(role)
        response = self._send_and_parse_message(req, auth)
        if not response.HasField("validateQueriesResponse"):
            raise Exception(
                "Expected validateQueriesResponse, got "
                + response.WhichOneof("waterfront_response")
            )
        return response.validateQueriesResponse

    def validate_dataset(
            self,
            manifest_hash: bytes,
            key: Key,
            role: str = None
    ):
        """
        Checks that the dataset can be processed on the enclave side
        """
        _, auth = self._get_auth_for_role(role)
        req = WaterfrontRequest()
        req.validateDatasetRequest.manifestHash = manifest_hash
        req.validateDatasetRequest.encryptionKey.material = key.material
        req.validateDatasetRequest.encryptionKey.salt = key.salt
        response = self._send_and_parse_message(req, auth)
        if not response.HasField("validateDatasetResponse"):
            raise Exception(
                "Expected validateDatasetResponse, got "
                + response.WhichOneof("waterfront_response")
            )
        return response.validateDatasetResponse

    def make_sql_query(
            self,
            data_room_hash: bytes,
            query_name: str,
            polling_options: PollingOptions,
            role: str = None
    ) -> SqlQueryFinished:
        """
        Launches a new SQL query job with the provided query name and the currently
        provisioned datasets and waits for its completion returning the results
        """
        req = WaterfrontRequest()
        req.sqlQueryRequest.queryName = query_name
        req.sqlQueryRequest.dataRoomHash = data_room_hash

        role_name, auth = self._get_auth_for_role(role)
        req.sqlQueryRequest.auth.role = role_name

        access_token = auth._get_access_token()
        if access_token is not None:
            req.sqlQueryRequest.auth.passwordSha256 = access_token

        response = self._submit_query_request(req, auth)
        if response.HasField("finished"):
            return response.finished

        job_id = response.inProgress.jobId
        while True:
            # poll status
            status = self.get_job_status(job_id, role)
            if status is True:
                response = self.get_job_results(job_id, role)
                return response
            time.sleep(polling_options.interval/1000)

    def _concatenate_sql_query_responses(
            self,
            responses: List[WaterfrontResponse]
    ) -> SqlQueryResponse:
        if len(responses) == 1:
            return responses[0].sqlQueryResponse
        contents = []
        final_response = SqlQueryResponse()
        for response in responses:
            if not response.HasField("sqlQueryResponse"):
                raise Exception("Expected query response, got "
                                + response.WhichOneof("waterfront_response"))
            if response.sqlQueryResponse.HasField("inProgress"):
                return response.sqlQueryResponse
            if response.sqlQueryResponse.HasField("finished"):
                final_response.finished.header[:] = response.sqlQueryResponse.finished.header
                contents.append(response.sqlQueryResponse.finished.data)
            else:
                raise Exception("Expected inProgress or finished query response")
        final_response.finished.data = b''.join(contents)
        return final_response

    # submit a query, once.
    def _submit_query_request(self, request: WaterfrontRequest, auth: Auth) -> SqlQueryResponse:
        responses = self._send_message_many_responses(request, auth)
        return self._concatenate_sql_query_responses(responses)

    def make_sql_query_poll(
            self, data_room_hash: bytes,
            query_name: str,
            role: str = None
    ) -> SqlQueryResponse:
        """
        Launches a new SQL query job with the provided query name and the currently
        provisioned datasets
        """
        req = WaterfrontRequest()
        req.sqlQueryRequest.queryName = query_name
        req.sqlQueryRequest.dataRoomHash = data_room_hash

        role_name, auth = self._get_auth_for_role(role)
        req.sqlQueryRequest.auth.role = role_name

        access_token = auth._get_access_token()
        if access_token is not None:
            req.sqlQueryRequest.auth.passwordSha256 = access_token

        return self._submit_query_request(req, auth)

    def get_job_status(self, job_id: bytes, role: str = None) -> bool:
        """
        Returns the status of the provided `job_id`
        """
        req = WaterfrontRequest()
        req.jobStatusRequest.jobId = job_id
        role_name, auth = self._get_auth_for_role(role)
        req.jobStatusRequest.auth.role = role_name

        access_token = auth._get_access_token()
        if access_token is not None:
            req.jobStatusRequest.auth.passwordSha256 = access_token

        response = self._send_and_parse_message(req, auth)
        if not response.HasField("jobStatusResponse"):
            raise Exception(
                "Expected jobStatusResponse, got "
                + response.WhichOneof("waterfront_response")
            )
        if not response.jobStatusResponse.HasField("completed"):
            raise Exception(
                "Expected completed field, did not find it.")
        return response.jobStatusResponse.completed

    def get_job_results(self, job_id: bytes, role: str = None) -> SqlQueryFinished:
        """
        Returns the results of the provided `job_id`
        """
        req = WaterfrontRequest()
        req.getResultsRequest.jobId = job_id
        role_name, auth = self._get_auth_for_role(role)
        req.getResultsRequest.auth.role = role_name

        access_token = auth._get_access_token()
        if access_token is not None:
            req.getResultsRequest.auth.passwordSha256 = access_token

        responses = self._send_message_many_responses(req, auth)
        final_response = self._concatenate_sql_query_responses(responses)
        if final_response.HasField("finished"):
            return final_response.finished
        else:
            raise Exception("Expected finished sql query response, got "
                            + final_response.WhichOneof("sql_query_response"))

    def _get_enclave_pubkey(self):
        pub_keyB = bytearray(self.quote.reportdata[:32])
        return chily.PublicKey.from_bytes(pub_keyB)

    def _encrypt_and_encode_data(self, data: bytes, auth: Auth) -> bytes:
        nonce = chily.Nonce.from_random()
        cipher = chily.Cipher(
            self.keypair.secret, self._get_enclave_pubkey()
        )
        enc_data = cipher.encrypt(data, nonce)
        public_keys = bytes(self.keypair.public_key.bytes) + bytes(self._get_enclave_pubkey().bytes)
        signature = auth._sign(public_keys)
        shared_key = bytes(self.keypair.secret.diffie_hellman(self._get_enclave_pubkey()).bytes)
        hkdf = HKDF(algorithm=hashes.SHA512(), length=64, info=b"IdP KDF Context", salt=b"")
        mac_key = hkdf.derive(shared_key)
        mac_tag = hmac.digest(mac_key, auth._get_user_id().encode(), "sha512")
        sigma_auth = Sigma(signature, mac_tag, auth)
        return datanoncepubkey_to_message(
            bytes(enc_data),
            bytes(nonce.bytes),
            bytes(self.keypair.public_key.bytes),
            sigma_auth
        )

    def _decode_and_decrypt_data(self, data: bytes) -> bytes:
        dec_data, nonceB, _ = message_to_datanoncepubkey(data)
        cipher = chily.Cipher(
            self.keypair.secret, self._get_enclave_pubkey()
        )
        return cipher.decrypt(dec_data, chily.Nonce.from_bytes(nonceB))

    def _send_and_parse_message(self, message: WaterfrontRequest, auth: Auth) -> WaterfrontResponse:
        waterfront_response = WaterfrontResponse()
        self._send_message(message, waterfront_response, auth)
        if waterfront_response.HasField("failure"):
            raise Exception(waterfront_response.failure)
        return waterfront_response

    def _send_message(self, message: Message, response_object: WaterfrontResponse, auth: Auth):
        enclave_response_bytes = self._send_message_raw(message, auth)
        response_container = Response()
        parse_length_delimited(enclave_response_bytes, response_container)
        if response_container.HasField("unsuccessfulResponse"):
            raise Exception(response_container.unsuccessfulResponse)
        decrypted_response = self._decode_and_decrypt_data(response_container.successfulResponse)
        parse_length_delimited(decrypted_response, response_object)

    def _send_message_many_responses(self, message: Message, auth: Auth) -> List[WaterfrontResponse]:
        enclave_response_bytes = self._send_message_raw(message, auth)
        responses = []
        offset = 0
        while offset < len(enclave_response_bytes):
            response_container = Response()
            offset += parse_length_delimited(enclave_response_bytes[offset:], response_container)
            if response_container.HasField("unsuccessfulResponse"):
                raise Exception(response_container.unsuccessfulResponse)
            else:
                waterfront_response = WaterfrontResponse()
                decrypted_response = self._decode_and_decrypt_data(
                    response_container.successfulResponse)
                parse_length_delimited(decrypted_response, waterfront_response)
                if waterfront_response.HasField("failure"):
                    raise Exception(waterfront_response.failure)
                responses.append(waterfront_response)
        return responses

    def _send_message_raw(self, message: Message, auth: Auth) -> bytes:
        encrypted = self._encrypt_and_encode_data(serialize_length_delimited(message), auth)
        request = Request()
        request.avatoRequest = encrypted
        url = Endpoints.SESSION_MESSAGES.replace(":sessionId", self.session_id)
        serialized_request = serialize_length_delimited(request)
        enclave_message = B64EncodedMessage(data=b64encode(serialized_request).decode("ascii"))

        enclave_response: B64EncodedMessage = self.client.api.post(
            url, json.dumps(enclave_message), {"Content-type": "application/json"}
        ).json()
        enclave_response_bytes = b64decode(enclave_response["data"])
        return enclave_response_bytes

    def _get_auth_for_role(self, role: str = None) -> Tuple[str, Auth]:
        if len(self.auth) == 0:
            raise Exception("No auth objects")
        if role is None:
            if len(self.auth) > 1:
                raise Exception("No role specififed but multiple auths")
            else:
                return (list(self.auth.keys())[0], list(self.auth.values())[0])
        else:
            auth = self.auth.get(role)
            if auth is not None:
                return role, auth
            else:
                raise Exception("No auth found for specififed role")



from sgx_ias_structs import QuoteBody as _QuoteBody
from asn1crypto import pem
from oscrypto import asymmetric
from certvalidator import CertificateValidator, ValidationContext
from enum import IntFlag
import json

intel_sgx_root_ca = b"""
-----BEGIN CERTIFICATE-----
MIIFSzCCA7OgAwIBAgIJANEHdl0yo7CUMA0GCSqGSIb3DQEBCwUAMH4xCzAJBgNV
BAYTAlVTMQswCQYDVQQIDAJDQTEUMBIGA1UEBwwLU2FudGEgQ2xhcmExGjAYBgNV
BAoMEUludGVsIENvcnBvcmF0aW9uMTAwLgYDVQQDDCdJbnRlbCBTR1ggQXR0ZXN0
YXRpb24gUmVwb3J0IFNpZ25pbmcgQ0EwIBcNMTYxMTE0MTUzNzMxWhgPMjA0OTEy
MzEyMzU5NTlaMH4xCzAJBgNVBAYTAlVTMQswCQYDVQQIDAJDQTEUMBIGA1UEBwwL
U2FudGEgQ2xhcmExGjAYBgNVBAoMEUludGVsIENvcnBvcmF0aW9uMTAwLgYDVQQD
DCdJbnRlbCBTR1ggQXR0ZXN0YXRpb24gUmVwb3J0IFNpZ25pbmcgQ0EwggGiMA0G
CSqGSIb3DQEBAQUAA4IBjwAwggGKAoIBgQCfPGR+tXc8u1EtJzLA10Feu1Wg+p7e
LmSRmeaCHbkQ1TF3Nwl3RmpqXkeGzNLd69QUnWovYyVSndEMyYc3sHecGgfinEeh
rgBJSEdsSJ9FpaFdesjsxqzGRa20PYdnnfWcCTvFoulpbFR4VBuXnnVLVzkUvlXT
L/TAnd8nIZk0zZkFJ7P5LtePvykkar7LcSQO85wtcQe0R1Raf/sQ6wYKaKmFgCGe
NpEJUmg4ktal4qgIAxk+QHUxQE42sxViN5mqglB0QJdUot/o9a/V/mMeH8KvOAiQ
byinkNndn+Bgk5sSV5DFgF0DffVqmVMblt5p3jPtImzBIH0QQrXJq39AT8cRwP5H
afuVeLHcDsRp6hol4P+ZFIhu8mmbI1u0hH3W/0C2BuYXB5PC+5izFFh/nP0lc2Lf
6rELO9LZdnOhpL1ExFOq9H/B8tPQ84T3Sgb4nAifDabNt/zu6MmCGo5U8lwEFtGM
RoOaX4AS+909x00lYnmtwsDVWv9vBiJCXRsCAwEAAaOByTCBxjBgBgNVHR8EWTBX
MFWgU6BRhk9odHRwOi8vdHJ1c3RlZHNlcnZpY2VzLmludGVsLmNvbS9jb250ZW50
L0NSTC9TR1gvQXR0ZXN0YXRpb25SZXBvcnRTaWduaW5nQ0EuY3JsMB0GA1UdDgQW
BBR4Q3t2pn680K9+QjfrNXw7hwFRPDAfBgNVHSMEGDAWgBR4Q3t2pn680K9+Qjfr
NXw7hwFRPDAOBgNVHQ8BAf8EBAMCAQYwEgYDVR0TAQH/BAgwBgEB/wIBADANBgkq
hkiG9w0BAQsFAAOCAYEAeF8tYMXICvQqeXYQITkV2oLJsp6J4JAqJabHWxYJHGir
IEqucRiJSSx+HjIJEUVaj8E0QjEud6Y5lNmXlcjqRXaCPOqK0eGRz6hi+ripMtPZ
sFNaBwLQVV905SDjAzDzNIDnrcnXyB4gcDFCvwDFKKgLRjOB/WAqgscDUoGq5ZVi
zLUzTqiQPmULAQaB9c6Oti6snEFJiCQ67JLyW/E83/frzCmO5Ru6WjU4tmsmy8Ra
Ud4APK0wZTGtfPXU7w+IBdG5Ez0kE1qzxGQaL4gINJ1zMyleDnbuS8UicjJijvqA
152Sq049ESDz+1rRGc2NVEqh1KaGXmtXvqxXcTB+Ljy5Bw2ke0v8iGngFBPqCTVB
3op5KBG3RjbF6RRSzwzuWfL7QErNC8WEy5yDVARzTA5+xmBc388v9Dm21HGfcC8O
DD+gT9sSpssq0ascmvH49MOgjt1yoysLtdCtJW/9FZpoOypaHx0R+mJTLwPXVMrv
DaVzWh5aiEx+idkSGMnX
-----END CERTIFICATE-----
"""

class QuoteBody:
    """Represents the body of the SGX IAS Quote"""

    def __init__(self, quote):
        if not isinstance(quote, _QuoteBody):
            raise Exception("QuoteBody must be converted from sgx_ias_structs repr.")
        self.version = quote.version
        self.sign_type = quote.sign_type
        self.qe_svn = quote.qe_svn
        self.pce_svn = quote.pce_svn
        self.xeid = quote.xeid
        self.epid_group_id = quote.epid_group_id
        self.basename = quote.basename
        self.reportdata = quote.reportdata
        self.cpusvn = quote.cpusvn
        self.mrenclave = quote.mrenclave
        self.mrsigner = quote.mrsigner
        self.isvprodid = quote.isvprodid
        self.isvsvn = quote.isvsvn
        self.flags = quote.flags

    def __str__(self):
        obj_dict = {
            k: bytes(v).hex() if isinstance(v, (list, bytes)) else v
            for (k, v) in self.__dict__.items()
        }
        return json.dumps(obj_dict, indent=4)

    @classmethod
    def from_base64_string(cls, data):
        return cls(_QuoteBody.from_base64_string(data))


class CertificateValidationError(Exception):
    """Raised when the certificate validation failed"""

    pass


class SignatureValidationError(Exception):
    """Raised when the signature validation failed"""

    pass


class MessageParsingError(Exception):
    """Raised when the json message parsing failed"""

    pass


class ISVEnclaveQuoteStatusError(Exception):
    """Raised when the isv enclave quote status is not in an accepted status"""

    pass


class EnclaveQuoteFlagsError(Exception):
    """Raised when the flags in quote body don't match expected values"""

    pass


class MeasurementMismatchError(Exception):
    """Raised when enclave measurement does not match expected value"""

    pass


class Verification:
    class IASAttributeFlags(IntFlag):
        INIT = 1
        DEBUG = 2
        MODE64BIT = 4
        PROVISIONKEY = 8
        EINITTOKENKEY = 16

    def __init__(
        self,
        expected_measurement=None,
        accept_debug=False,
        accept_configuration_needed=False,
        accept_group_out_of_date=False,
    ):
        self.expected_measurement = expected_measurement
        self.accept_debug = accept_debug
        self.accept_configuration_needed = accept_configuration_needed
        self.accept_group_out_of_date = accept_group_out_of_date
        trust_roots = []
        for _, _, der_bytes in pem.unarmor(intel_sgx_root_ca, multiple=True): # type: ignore
            trust_roots.append(der_bytes)
        self.context = ValidationContext(trust_roots=trust_roots)

    def verify(self, certificate, message, signature) -> QuoteBody:
        """
        :param certificate:
            A byte string of the certificate
 
        :param message:
            A byte string of the data the signature is for
 
        :param signature:
            A byte string of the data the signature is for
 
        :raises:
            CertificateValidationError
            SignatureValidationError
            MessageParsingError
            ISVEnclaveQuoteStatusError
            EnclaveQuoteFlagsError
            MeasurementMismatchError
 
        :return:
            the QuoteBody inside the message
        """

        # Step 1: validate certificate with Intel SGX attestation root CA
        try:
            validator = CertificateValidator(
                certificate, validation_context=self.context
            )
            validator.validate_usage(set(["digital_signature"]))
        except:
            raise CertificateValidationError

        # Step 2: verify message signature
        try:
            pubk = asymmetric.load_public_key(certificate)
            asymmetric.rsa_pkcs1v15_verify(pubk, signature, message, "sha256")
        except:
            raise SignatureValidationError

        # Step 3: parse message and get quote body
        try:
            message_dic = json.loads(message)
            quote_body_encoded = message_dic["isvEnclaveQuoteBody"]
            isv_enclave_quote_status = message_dic["isvEnclaveQuoteStatus"]
            quote_body = _QuoteBody.from_base64_string(quote_body_encoded)
        except:
            raise MessageParsingError

        # Step 4: check isv enclave quote status
        if isv_enclave_quote_status == "OK":
            pass
        elif isv_enclave_quote_status == "CONFIGURATION_NEEDED":
            if not self.accept_configuration_needed:
                raise ISVEnclaveQuoteStatusError
        elif isv_enclave_quote_status == "GROUP_OUT_OF_DATE":
            if not self.accept_group_out_of_date:
                raise ISVEnclaveQuoteStatusError
        else:
            raise ISVEnclaveQuoteStatusError

        # Step 5: check enclave quote flags
        flags = quote_body.flags
        if not (flags & Verification.IASAttributeFlags.INIT):
            raise EnclaveQuoteFlagsError
        if not (flags & Verification.IASAttributeFlags.MODE64BIT):
            raise EnclaveQuoteFlagsError
        if flags & Verification.IASAttributeFlags.DEBUG:
            if not self.accept_debug:
                raise EnclaveQuoteFlagsError

        # Step 6: assert expected measurement
        if self.expected_measurement:
            measurement = bytes(quote_body.mrenclave).hex()
            if not (measurement == self.expected_measurement):
                raise MeasurementMismatchError(
                    f"Expected: {self.expected_measurement}. Actual: {measurement}."
                )

        return QuoteBody(quote_body)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AVATOREQUEST_FIELD_NUMBER: builtins.int
    EXTENSIONMESSAGE_FIELD_NUMBER: builtins.int
    avatoRequest: builtins.bytes = ...

    @property
    def extensionMessage(self) -> global___ExtensionMessage: ...

    def __init__(self,
        *,
        avatoRequest : typing.Optional[builtins.bytes] = ...,
        extensionMessage : typing.Optional[global___ExtensionMessage] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"avatoRequest",b"avatoRequest",u"extensionMessage",b"extensionMessage",u"request",b"request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"avatoRequest",b"avatoRequest",u"extensionMessage",b"extensionMessage",u"request",b"request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"request",b"request"]) -> typing_extensions.Literal["avatoRequest","extensionMessage"]: ...
global___Request = Request

class ExtensionMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    name: typing.Text = ...
    payload: builtins.bytes = ...

    def __init__(self,
        *,
        name : typing.Optional[typing.Text] = ...,
        payload : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"name",b"name",u"payload",b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"name",b"name",u"payload",b"payload"]) -> None: ...
global___ExtensionMessage = ExtensionMessage

class Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SUCCESSFULRESPONSE_FIELD_NUMBER: builtins.int
    UNSUCCESSFULRESPONSE_FIELD_NUMBER: builtins.int
    successfulResponse: builtins.bytes = ...
    unsuccessfulResponse: typing.Text = ...

    def __init__(self,
        *,
        successfulResponse : typing.Optional[builtins.bytes] = ...,
        unsuccessfulResponse : typing.Optional[typing.Text] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"response",b"response",u"successfulResponse",b"successfulResponse",u"unsuccessfulResponse",b"unsuccessfulResponse"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"response",b"response",u"successfulResponse",b"successfulResponse",u"unsuccessfulResponse",b"unsuccessfulResponse"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"response",b"response"]) -> typing_extensions.Literal["successfulResponse","unsuccessfulResponse"]: ...
global___Response = Response

class DataNoncePubkey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    NONCE_FIELD_NUMBER: builtins.int
    PUBKEY_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    nonce: builtins.bytes = ...
    pubkey: builtins.bytes = ...

    @property
    def auth(self) -> global___Authentication: ...

    def __init__(self,
        *,
        data : typing.Optional[builtins.bytes] = ...,
        nonce : typing.Optional[builtins.bytes] = ...,
        pubkey : typing.Optional[builtins.bytes] = ...,
        auth : typing.Optional[global___Authentication] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"data",b"data",u"nonce",b"nonce",u"pubkey",b"pubkey"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"data",b"data",u"nonce",b"nonce",u"pubkey",b"pubkey"]) -> None: ...
global___DataNoncePubkey = DataNoncePubkey

class Authentication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PKI_FIELD_NUMBER: builtins.int

    @property
    def pki(self) -> global___Pki: ...

    def __init__(self,
        *,
        pki : typing.Optional[global___Pki] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pki",b"pki"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pki",b"pki"]) -> None: ...
global___Authentication = Authentication

class Pki(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CERTCHAIN_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    IDMAC_FIELD_NUMBER: builtins.int
    certChain: builtins.bytes = ...
    signature: builtins.bytes = ...
    idMac: builtins.bytes = ...

    def __init__(self,
        *,
        certChain : typing.Optional[builtins.bytes] = ...,
        signature : typing.Optional[builtins.bytes] = ...,
        idMac : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"certChain",b"certChain",u"idMac",b"idMac",u"signature",b"signature"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"certChain",b"certChain",u"idMac",b"idMac",u"signature",b"signature"]) -> None: ...
global___Pki = Pki

class DataNonce(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    NONCE_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    nonce: builtins.bytes = ...

    def __init__(self,
        *,
        data : typing.Optional[builtins.bytes] = ...,
        nonce : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"data",b"data",u"nonce",b"nonce"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"nonce",b"nonce"]) -> None: ...
global___DataNonce = DataNonce

class SealedEncryptedMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ENCRYPTEDMESSAGE_FIELD_NUMBER: builtins.int
    SEALINGKEYPARAMS_FIELD_NUMBER: builtins.int
    sealingKeyParams: builtins.bytes = ...

    @property
    def encryptedMessage(self) -> global___DataNonce: ...

    def __init__(self,
        *,
        encryptedMessage : typing.Optional[global___DataNonce] = ...,
        sealingKeyParams : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"encryptedMessage",b"encryptedMessage",u"sealingKeyParams",b"sealingKeyParams"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"encryptedMessage",b"encryptedMessage",u"sealingKeyParams",b"sealingKeyParams"]) -> None: ...
global___SealedEncryptedMessage = SealedEncryptedMessage

class EncryptionHeader(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHILYKEY_FIELD_NUMBER: builtins.int

    @property
    def chilyKey(self) -> global___ChilyKey: ...

    def __init__(self,
        *,
        chilyKey : typing.Optional[global___ChilyKey] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"chilyKey",b"chilyKey",u"encryptionHeader",b"encryptionHeader"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chilyKey",b"chilyKey",u"encryptionHeader",b"encryptionHeader"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"encryptionHeader",b"encryptionHeader"]) -> typing_extensions.Literal["chilyKey"]: ...
global___EncryptionHeader = EncryptionHeader

class ChilyKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEYID_FIELD_NUMBER: builtins.int
    ENCRYPTIONNONCE_FIELD_NUMBER: builtins.int
    keyId: builtins.bytes = ...
    encryptionNonce: builtins.bytes = ...

    def __init__(self,
        *,
        keyId : typing.Optional[builtins.bytes] = ...,
        encryptionNonce : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"encryptionNonce",b"encryptionNonce",u"keyId",b"keyId"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"encryptionNonce",b"encryptionNonce",u"keyId",b"keyId"]) -> None: ...
global___ChilyKey = ChilyKey

class IntegrityHeader(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BODYSHA256_FIELD_NUMBER: builtins.int
    RESULTSHA256_FIELD_NUMBER: builtins.int

    @property
    def bodySha256(self) -> global___BodySha256: ...

    @property
    def resultSha256(self) -> global___ResultSha256: ...

    def __init__(self,
        *,
        bodySha256 : typing.Optional[global___BodySha256] = ...,
        resultSha256 : typing.Optional[global___ResultSha256] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"bodySha256",b"bodySha256",u"integrity_header",b"integrity_header",u"resultSha256",b"resultSha256"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"bodySha256",b"bodySha256",u"integrity_header",b"integrity_header",u"resultSha256",b"resultSha256"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"integrity_header",b"integrity_header"]) -> typing_extensions.Literal["bodySha256","resultSha256"]: ...
global___IntegrityHeader = IntegrityHeader

class BodySha256(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___BodySha256 = BodySha256

class ResultSha256(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMPUTATIONSHA256_FIELD_NUMBER: builtins.int
    computationSha256: builtins.bytes = ...

    def __init__(self,
        *,
        computationSha256 : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"computationSha256",b"computationSha256"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"computationSha256",b"computationSha256"]) -> None: ...
global___ResultSha256 = ResultSha256

class VersionHeader(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VERSION_FIELD_NUMBER: builtins.int
    version: builtins.int = ...

    def __init__(self,
        *,
        version : typing.Optional[builtins.int] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"version",b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"version",b"version"]) -> None: ...
global___VersionHeader = VersionHeader

class ChunkHeader(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EXTRAENTROPY_FIELD_NUMBER: builtins.int
    FORMATIDENTIFIER_FIELD_NUMBER: builtins.int
    extraEntropy: builtins.bytes = ...
    formatIdentifier: typing.Text = ...

    def __init__(self,
        *,
        extraEntropy : typing.Optional[builtins.bytes] = ...,
        formatIdentifier : typing.Optional[typing.Text] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"extraEntropy",b"extraEntropy",u"formatIdentifier",b"formatIdentifier"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"extraEntropy",b"extraEntropy",u"formatIdentifier",b"formatIdentifier"]) -> None: ...
global___ChunkHeader = ChunkHeader



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: column_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='column_type.proto',
  package='column_type',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11\x63olumn_type.proto\x12\x0b\x63olumn_type\"Q\n\nColumnType\x12\x31\n\rprimitiveType\x18\x01 \x02(\x0e\x32\x1a.column_type.PrimitiveType\x12\x10\n\x08nullable\x18\x02 \x02(\x08*3\n\rPrimitiveType\x12\t\n\x05INT64\x10\x01\x12\n\n\x06STRING\x10\x02\x12\x0b\n\x07\x46LOAT64\x10\x03'
)

_PRIMITIVETYPE = _descriptor.EnumDescriptor(
  name='PrimitiveType',
  full_name='column_type.PrimitiveType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INT64', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLOAT64', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=117,
  serialized_end=168,
)
_sym_db.RegisterEnumDescriptor(_PRIMITIVETYPE)

PrimitiveType = enum_type_wrapper.EnumTypeWrapper(_PRIMITIVETYPE)
INT64 = 1
STRING = 2
FLOAT64 = 3



_COLUMNTYPE = _descriptor.Descriptor(
  name='ColumnType',
  full_name='column_type.ColumnType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='primitiveType', full_name='column_type.ColumnType.primitiveType', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nullable', full_name='column_type.ColumnType.nullable', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=115,
)

_COLUMNTYPE.fields_by_name['primitiveType'].enum_type = _PRIMITIVETYPE
DESCRIPTOR.message_types_by_name['ColumnType'] = _COLUMNTYPE
DESCRIPTOR.enum_types_by_name['PrimitiveType'] = _PRIMITIVETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ColumnType = _reflection.GeneratedProtocolMessageType('ColumnType', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNTYPE,
  '__module__' : 'column_type_pb2'
  # @@protoc_insertion_point(class_scope:column_type.ColumnType)
  })
_sym_db.RegisterMessage(ColumnType)


# @@protoc_insertion_point(module_scope)
